@@ -1,5 +1,4 @@
-"""
-"""
+"""A programmatic API for using Otter-Grader"""
 
 __all__ = ["export_notebook", "grade_submission"]
 
@@ -13,16 +12,13 @@ from contextlib import redirect_stdout
 try:
     from contextlib import nullcontext
 except ImportError:
-    from .utils import nullcontext # nullcontext is new in Python 3.7
+    from .utils import nullcontext  # nullcontext is new in Python 3.7
 
-from .argparser import get_parser
 from .export import export_notebook
 from .run import main as run_grader
 
-PARSER = get_parser()
-ARGS_STARTER = ["run"]
 
-def grade_submission(ag_path, submission_path, quiet=False, debug=False):
+def grade_submission(submission_path, ag_path="autograder.zip", quiet=False, debug=False):
     """
     Runs non-containerized grading on a single submission at ``submission_path`` using the autograder 
     configuration file at ``ag_path``. 
@@ -35,8 +31,8 @@ def grade_submission(ag_path, submission_path, quiet=False, debug=False):
     Print statements executed during grading can be suppressed with ``quiet``.
 
     Args:
-        ag_path (``str``): path to autograder zip file
         submission_path (``str``): path to submission file
+        ag_path (``str``): path to autograder zip file
         quiet (``bool``, optional): whether to suppress print statements during grading; default 
             ``False``
         debug (``bool``, optional): whether to run the submission in debug mode (without ignoring
@@ -49,27 +45,16 @@ def grade_submission(ag_path, submission_path, quiet=False, debug=False):
 
     dp = tempfile.mkdtemp()
 
-    args_list = ARGS_STARTER.copy()
-    args_list.extend([
-        "-a", ag_path,
-        "-o", dp,
-        submission_path,
-        "--no-logo",
-    ])
-
-    if debug:
-        args_list.append("--debug")
-
-    args = PARSER.parse_args(args_list)
-
     if quiet:
         f = open(os.devnull, "w")
         cm = redirect_stdout(f)
     else:
         cm = nullcontext()
-        
+
+    # TODO: is the output_dir argument of run_grader necessary here?
     with cm:
-        results = run_grader(**vars(args))
+        results = run_grader(
+            submission_path, autograder=ag_path, output_dir=dp, no_logo=True, debug=debug)
 
     if quiet:
         f.close()
