@@ -1,9 +1,7 @@
-"""
-Otter Assign command-line utility
-"""
+"""Assignment creation tool for Otter-Grader"""
 
-import os
 import json
+import os
 import pathlib
 import warnings
 
@@ -13,11 +11,13 @@ from .utils import run_tests, write_otter_config_file, run_generate_autograder
 from ..export import export_notebook
 from ..export.exporters import WkhtmltopdfNotFoundError
 from ..plugins import PluginCollection
-from ..utils import get_relpath, block_print
+from ..utils import block_print, get_relpath, knit_rmd_file
 
-def main(master, result, no_pdfs, no_run_tests, username, password, debug, **kwargs):
+
+def main(master, result, *, no_pdfs=False, no_run_tests=False, username=None, password=None, 
+         debug=False, v1=False):
     """
-    Runs Otter Assign on a master notebook
+    Runs Otter Assign on a master notebook.
     
     Args:
         master (``str``): path to master notebook
@@ -28,45 +28,44 @@ def main(master, result, no_pdfs, no_run_tests, username, password, debug, **kwa
         username (``str``): a username for Gradescope for generating a token
         password (``str``): a password for Gradescope for generating a token
         debug (``bool``): whether to run in debug mode (without ignoring errors during testing)
-        **kwargs: ignored kwargs (a remnant of how the argument parser is built)
+        v1 (``bool``): whether to use Otter Assign Format v1 instead of v0
     """
+    if not v1:
+        warnings.warn(
+            "Otter Assign format v0 will be deprecated in Otter v4 and removed in a later release.",
+            FutureWarning)
+            
+        from .v0 import main as v0_main
+        return v0_main(master, result, no_pdfs=no_pdfs, no_run_tests=no_run_tests, username=username, 
+            password=password, debug=debug)
+
     master, result = pathlib.Path(os.path.abspath(master)), pathlib.Path(os.path.abspath(result))
     print("Generating views...")
 
     assignment = Assignment()
 
-    # # check language
-    # if lang is not None:
-    #     lang = lang.lower()
-    #     assert lang in ["r", "python"], f"Language {lang} is not valid"
-    #     assignment.lang = lang
-    
-    # TODO: update this condition
-    if True:
-        result = get_relpath(master.parent, result)
-        orig_dir = os.getcwd()
-        os.chdir(master.parent)
-        # master = pathlib.Path(master.name)
+    result = get_relpath(master.parent, result)
+    orig_dir = os.getcwd()
+    os.chdir(master.parent)
     
     assignment.master, assignment.result = master, result
-    # assignment.files = files
 
     if assignment.is_rmd:
         from .rmarkdown_adapter.output import write_output_directories
     else:
         from .output import write_output_directories
 
-    # # update requirements
-    # requirements = requirements
-    # if requirements is None and os.path.isfile("requirements.txt"):
-    #     requirements = "requirements.txt"
-    # if requirements:
-    #     assert os.path.isfile(requirements), f"Requirements file {requirements} not found"
-    # assignment.requirements = requirements
-    
     try:
         output_nb_path = write_output_directories(master, result, assignment)
 
+        # update seed variables
+        if isinstance(assignment.seed, dict):
+            if assignment.generate:
+                if assignment.generate is True:
+                    assignment.generate = {}
+                assignment.generate["seed"] = assignment.seed["autograder_value"]
+                assignment.generate["seed_variable"] = assignment.seed["variable"]
+
         # check that we have a seed if needed
         if assignment.seed_required:
             generate_args = assignment.generate
@@ -87,38 +86,62 @@ def main(master, result, no_pdfs, no_run_tests, username, password, debug, **kwa
                 assignment.generate["plugins"].extend(plugins)
         else:
             pc = None
+
+        # generate Gradescope autograder zipfile
+        if assignment.generate:
+            print("Generating autograder zipfile...")
+            run_generate_autograder(result, assignment, username, password, plugin_collection=pc)
         
         # generate PDF of solutions
-        if assignment.solutions_pdf and not assignment.is_rmd and not no_pdfs:
+        if assignment.solutions_pdf and not no_pdfs:
             print("Generating solutions PDF...")
             filtering = assignment.solutions_pdf == 'filtered'
 
-            try:
-                export_notebook(
-                    str(result / 'autograder' / master.name),
-                    dest=str(result / 'autograder' / (master.stem + '-sol.pdf')),
-                    filtering=filtering,
-                    pagebreaks=filtering,
-                    exporter_type="html",
-                )
-            except WkhtmltopdfNotFoundError:
-                export_notebook(
-                    str(result / 'autograder' / master.name),
-                    dest=str(result / 'autograder' / (master.stem + '-sol.pdf')),
-                    filtering=filtering,
-                    pagebreaks=filtering,
-                )
+            src = os.path.abspath(str(result / 'autograder' / master.name))
+            dst = os.path.abspath(str(result / 'autograder' / (master.stem + '-sol.pdf')))
+        
+            if not assignment.is_rmd:
+                try:
+                    export_notebook(
+                        src,
+                        dest=dst,
+                        filtering=filtering,
+                        pagebreaks=filtering,
+                        exporter_type="html",
+                    )
+                except WkhtmltopdfNotFoundError:
+                    export_notebook(
+                        src,
+                        dest=dst,
+                        filtering=filtering,
+                        pagebreaks=filtering,
+                    )
+
+            else:
+                if filtering:
+                    raise ValueError("Filtering is not supported with RMarkdown assignments")
+
+                knit_rmd_file(src, dst)
 
         # generate a tempalte PDF for Gradescope
-        if not assignment.is_rmd and assignment.template_pdf and not no_pdfs:
+        if assignment.template_pdf and not no_pdfs:
             print("Generating template PDF...")
-            export_notebook(
-                str(result / 'autograder' / master.name),
-                dest=str(result / 'autograder' / (master.stem + '-template.pdf')), 
-                filtering=True, 
-                pagebreaks=True, 
-                exporter_type="latex",
-            )
+            
+            src = os.path.abspath(str(result / 'autograder' / master.name))
+            dst = os.path.abspath(str(result / 'autograder' / (master.stem + '-template.pdf')))
+
+            if not assignment.is_rmd:
+                export_notebook(
+                    src,
+                    dest=dst, 
+                    filtering=True, 
+                    pagebreaks=True, 
+                    exporter_type="latex",
+                )
+
+            else:
+                raise ValueError(f"Filtering is not supported with RMarkdown assignments; use " + \
+                    "solutions_pdf to generate a Gradescope template instead.")
 
         # generate the .otter file if needed
         if not assignment.is_rmd and assignment.save_environment:
@@ -130,12 +153,6 @@ def main(master, result, no_pdfs, no_run_tests, username, password, debug, **kwa
             else:
                 write_otter_config_file(master, result, assignment)
 
-        # generate Gradescope autograder zipfile
-        if assignment.generate:
-            # TODO: move this to another function
-            print("Generating autograder zipfile...")
-            run_generate_autograder(result, assignment, username, password, plugin_collection=pc)
-
         # run tests on autograder notebook
         if assignment.run_tests and not no_run_tests and assignment.is_python:
             print("Running tests...")
@@ -153,16 +170,6 @@ def main(master, result, no_pdfs, no_run_tests, username, password, debug, **kwa
 
             run_tests(result / 'autograder' / master.name, debug=debug, seed=seed, plugin_collection=test_pc)
             print("All tests passed!")
-    
-    # for tests
-    except:
-        # TODO: change this condition
-        if True:
-            os.chdir(orig_dir)
 
-        raise
-
-    else:
-        # TODO: change this condition
-        if True:
-            os.chdir(orig_dir)
+    finally:
+        os.chdir(orig_dir)
