@@ -10,7 +10,7 @@ from ..utils import convert_config_description_dict
 _DEFAULT_ASSIGNMENT_CONFIGURATIONS_WITH_DESCRIPTIONS = [
     {
         "key": "requirements",
-        "description": "the path to a requirements.txt file",
+        "description": "the path to a requirements.txt file or a list of packages",
         "default": None,
     },
     {
