@@ -1,19 +1,19 @@
-"""
-Output writing for Otter Assign
-"""
+"""Output directory creation for Otter Assign"""
 
-import os
-import shutil
-import pathlib
-import warnings
 import nbformat
+import os
+import pathlib
+import shutil
+import tempfile
+import warnings
 
 from .constants import NB_VERSION
 from .notebook_transformer import transform_notebook
 from .plugins import replace_plugins_with_calls
-from .solutions import strip_ignored_lines, strip_solutions_and_output
+from .solutions import overwrite_seed_vars, strip_ignored_lines, strip_solutions_and_output
 from .tests import write_test
-from .utils import patch_copytree
+from .utils import get_notebook_language, patch_copytree, remove_cell_ids
+
 
 def write_autograder_dir(nb_path, output_nb_path, assignment):
     """
@@ -25,26 +25,31 @@ def write_autograder_dir(nb_path, output_nb_path, assignment):
         output_nb_path (``pathlib.Path``): path to output file
         assignment (``otter.assign.assignment.Assignment``): the assignment configurations
     """
+    assignment.notebook_basename = os.path.basename(str(output_nb_path))
+
     with open(nb_path) as f:
         nb = nbformat.read(f, as_version=NB_VERSION)
 
     if assignment.lang is None:
         try:
-            lang = nb["metadata"]["kernelspec"]["language"].lower()
-            assignment.lang = lang
+            assignment.lang = get_notebook_language(nb)
         except KeyError:
             warnings.warn("Could not auto-parse kernelspec from notebook; assuming Python")
             assignment.lang = "python"
 
-    output_dir = output_nb_path.parent
-    tests_dir = output_dir / 'tests'
-    os.makedirs(tests_dir, exist_ok=True)
-
     transformed_nb, test_files = transform_notebook(nb, assignment)
 
     # replace plugins
     transformed_nb = replace_plugins_with_calls(transformed_nb)
 
+    # update assignment.test_files for R notebooks
+    assignment.test_files |= assignment.is_r
+
+    output_dir = output_nb_path.parent
+    tests_dir = output_dir / 'tests'
+    if assignment.test_files:
+        os.makedirs(tests_dir, exist_ok=True)
+
     if assignment.requirements:
         output_fn = ("requirements.txt", "requirements.R")[assignment.is_r]
         if isinstance(assignment.requirements, list):
@@ -61,15 +66,25 @@ def write_autograder_dir(nb_path, output_nb_path, assignment):
     # strip out ignored lines
     transformed_nb = strip_ignored_lines(transformed_nb)
 
-    # write notebook
-    # with open(output_nb_path) as f:
-    # nbformat.write(transformed_nb, )
-    nbformat.write(transformed_nb, str(output_nb_path))
-
     # write tests
     test_ext = (".R", ".py")[assignment.is_python]
     for test_name, test_file in test_files.items():
-        write_test(tests_dir / (test_name + test_ext), test_file)
+        test_path = tests_dir / (test_name + test_ext) if assignment.test_files else test_name
+        write_test(transformed_nb, test_path, test_file, use_file=assignment.test_files)
+
+    # write a temp dir for otter generate tests
+    if assignment.generate:
+        assignment._temp_test_dir = pathlib.Path(tempfile.mkdtemp())
+        for test_name, test_file in test_files.items():
+            test_path = assignment._temp_test_dir / (test_name + test_ext)
+            write_test(transformed_nb, test_path, test_file, use_file=True)
+
+    # TODO: this is a bad practice and only a monkey-patch for #340. we shold do some better parsing
+    # of the nbformat version info to determine if this is necessary.
+    remove_cell_ids(transformed_nb)
+
+    # write notebook
+    nbformat.write(transformed_nb, str(output_nb_path))
 
     # copy files
     for file in assignment.files:
@@ -87,6 +102,7 @@ def write_autograder_dir(nb_path, output_nb_path, assignment):
             os.makedirs(output_dir / rel_path, exist_ok=True)
             shutil.copy(file, str(output_dir / rel_path))
 
+
 def write_student_dir(nb_name, autograder_dir, student_dir, assignment):
     """
     Copies the autograder (solutions) directory and removes extraneous files, strips solutions from
@@ -126,11 +142,16 @@ def write_student_dir(nb_name, autograder_dir, student_dir, assignment):
 
     nb = strip_solutions_and_output(nb)
 
+    # overwrite seed variable
+    if isinstance(assignment.seed, dict):
+        nb = overwrite_seed_vars(nb, assignment.seed["variable"], assignment.seed["student_value"])
+
+    # remove hidden tests from student directory
+    remove_hidden_tests_from_dir(nb, student_dir / 'tests', assignment, use_files=assignment.test_files)
+
     with open(student_nb_path, "w") as f:
         nbformat.write(nb, f)
 
-    # remove hidden tests from student directory
-    remove_hidden_tests_from_dir(student_dir / 'tests', assignment)
 
 def write_output_directories(master_nb_path, result_dir, assignment):
     """
