@@ -1,17 +1,20 @@
 import re
 
-from .utils import Cell
+from .utils import create_cell
 
 from ..constants import TEST_REGEX
 from ..r_adapter.tests import gen_suite
 from ..utils import get_source
 
+from ...test_files.abstract_test import TestFile
+
+
 def is_test_cell(cell):
     """
     Returns whether the current cell is a test cell
     
     Args:
-        cell (``otter.assign.rmarkdown_adapter.utils.Cell``): an Rmd file cell
+        cell (``nbformat.NotebookNode``): an Rmd file cell
 
     Returns:
         ``bool``: whether the cell is a test cell
@@ -21,6 +24,7 @@ def is_test_cell(cell):
     source = get_source(cell)
     return source and re.match(TEST_REGEX, source[1], flags=re.IGNORECASE)
 
+
 def gen_test_cell(question, tests, tests_dict, assignment):
     """
     Parses a list of test named tuples and creates a single test file. Adds this test file as a value
@@ -34,19 +38,22 @@ def gen_test_cell(question, tests, tests_dict, assignment):
         assignment (``otter.assign.assignment.Assignment``): the assignment configurations
 
     Returns:
-        ``otter.assign.rmarkdown_adapter.utils.Cell``: code cell calling ``ottr::check`` on this test
+        ``nbformat.NotebookNode``: code cell calling ``ottr::check`` on this test
     """
     source = f'```{{r}}\n. = ottr::check("tests/{question["name"]}.R")\n```'
-    cell = Cell("code", source)
+    cell = create_cell("code", source)
 
-    points = question.get('points', len(tests))
-    if isinstance(points, int):
-        if points % len(tests) == 0:
-            points = [points // len(tests) for _ in range(len(tests))]
-        else:
-            points = [points / len(tests) for _ in range(len(tests))]
-    assert isinstance(points, list) and len(points) == len(tests), \
-        f"Points for question {question['name']} could not be parsed:\n{points}"
+    points = question.get('points', None)
+    if isinstance(points, dict):
+        points = points.get('each', 1) * len(tests)
+    elif isinstance(points, list):
+        if len(points) != len(tests):
+            raise ValueError(
+                f"Error in question {question['name']}: length of 'points' is {len(points)} but there "
+                f"are {len(tests)} tests")
+
+    # check for errors in resolving points
+    tests = TestFile.resolve_test_file_points(points, tests)
 
     test = gen_suite(question['name'], tests, points)
 
