@@ -6,6 +6,7 @@ from .assign import main as assign
 from .check import main as check
 from .export import main as export
 from .generate import main as generate
+from .grade import _ALLOWED_EXTENSIONS
 from .grade import main as grade
 from .run import main as run
 from .version import print_version_info
@@ -105,8 +106,8 @@ defaults = grade.__kwdefaults__
 @click.option("-o", "--output-dir", default=defaults["output_dir"], help="Directory to which to write output")
 
 # submission format arguments
-@click.option("-s", "--scripts", is_flag=True, help="Flag to incidicate grading Python scripts")
 @click.option("-z", "--zips", is_flag=True, help="Whether submissions are zip files from Notebook.export")
+@click.option("--ext", type=click.Choice(_ALLOWED_EXTENSIONS), help="The extension to glob for submissions")
 
 # PDF export options
 @click.option("--pdfs", is_flag=True, help="Whether to copy notebook PDFs out of containers")
