@@ -3,20 +3,12 @@
 if [ "${BASE_IMAGE}" != "ucbdsinfra/otter-grader" ]; then
     apt-get clean
     apt-get update
-    apt-get install -y pandoc texlive-xetex texlive-fonts-recommended texlive-generic-recommended build-essential libcurl4-gnutls-dev libxml2-dev libssl-dev libgit2-dev
+    apt-get install -y pandoc texlive-xetex texlive-fonts-recommended texlive-generic-recommended build-essential libcurl4-gnutls-dev libxml2-dev libssl-dev libgit2-dev texlive-lang-chinese
 
     # install wkhtmltopdf
     wget --quiet -O /tmp/wkhtmltopdf.deb https://github.com/wkhtmltopdf/packaging/releases/download/0.12.6-1/wkhtmltox_0.12.6-1.bionic_amd64.deb
     apt-get install -y /tmp/wkhtmltopdf.deb
 
-    # install fandol font for xeCJK
-    wget -nv -O /tmp/fandol.zip https://mirrors.ctan.org/fonts/fandol.zip
-    unzip -d /tmp/fandol /tmp/fandol.zip
-    mkdir -p /usr/share/texlive/texmf-dist/fonts/opentype/public/fandol
-    cp /tmp/fandol/fandol/*.otf /usr/share/texlive/texmf-dist/fonts/opentype/public/fandol
-    mktexlsr
-    fc-cache
-
     # install conda
     wget -nv -O {{ autograder_dir }}/source/miniconda_install.sh "{{ miniconda_install_url }}"
     chmod +x {{ autograder_dir }}/source/miniconda_install.sh
