@@ -1,16 +1,16 @@
-"""
-"""
+"""Non-containerized single notebook grading for Otter-Grader"""
 
-import os
 import json
-import shutil
+import os
 import pickle
-import zipfile
+import shutil
 import tempfile
+import zipfile
 
 from .run_autograder import main as run_autograder
 
-def main(submission, autograder, output_dir, no_logo, debug, **kwargs):
+
+def main(submission, *, autograder="./autograder.zip", output_dir="./", no_logo=False, debug=False):
     """
     Grades a single submission using the autograder configuration ``autograder`` without containrization
 
@@ -29,7 +29,6 @@ def main(submission, autograder, output_dir, no_logo, debug, **kwargs):
     Returns:
         ``otter.test_files.GradingResults``: the grading results object
     """
-
     dp = tempfile.mkdtemp()
 
     try:
@@ -41,12 +40,18 @@ def main(submission, autograder, output_dir, no_logo, debug, **kwargs):
 
         with open(os.path.join(ag_dir, "submission_metadata.json"), "w+") as f:
             json.dump({}, f)
-        
+
         ag_zip = zipfile.ZipFile(autograder)
         ag_zip.extractall(os.path.join(ag_dir, "source"))
         ag_zip.close()
 
-        shutil.copy(submission, os.path.join(ag_dir, "submission"))
+        if os.path.splitext(submission)[1] == ".zip":
+            subm_zip = zipfile.ZipFile(submission)
+            subm_zip.extractall(os.path.join(ag_dir, "submission"))
+            subm_zip.close()
+
+        else:
+            shutil.copy(submission, os.path.join(ag_dir, "submission"))
 
         logo = not no_logo
         run_autograder(ag_dir, logo=logo, debug=debug)
@@ -58,11 +63,7 @@ def main(submission, autograder, output_dir, no_logo, debug, **kwargs):
         with open(results_pkl_path, "rb") as f:
             results = pickle.load(f)
 
-    except:
-        shutil.rmtree(dp)
-        raise
-    
-    else:
+    finally:
         shutil.rmtree(dp)
 
     return results
