@@ -2,15 +2,18 @@
 Classes for working with test files
 """
 
+import os
 import math
+import json
 import pprint
 import pickle
 
 from collections import namedtuple
 
-# from .abstract_test import TestCollection
+from .abstract_test import TestCase, TestCaseResult
 from .metadata_test import NotebookMetadataOKTestFile
 from .ok_test import OKTestFile
+from .ottr_test import OttrTestFile
 
 from ..check.logs import QuestionNotInLogException
 from ..run.run_autograder.constants import DEFAULT_OPTIONS
@@ -35,13 +38,10 @@ class GradingResults:
         results (``list`` of ``TestFile``): the list of test file objects summarized in this grade
     
     Attributes:
-        test_files (``list`` of ``TestFile``): the test files passed to the constructor
         results (``dict``): maps test names to ``GradingTestCaseResult`` named tuples containing the 
             test result information
         output (``str``): a string to include in the output field for Gradescope
         all_hidden (``bool``): whether all results should be hidden from the student on Gradescope
-        total (numeric): the total points earned by the submission
-        possible (numeric): the total points possible based on the tests
         tests (``list`` of ``str``): list of test names according to the keys of ``results``
     """
     def __init__(self, test_files):
@@ -52,26 +52,69 @@ class GradingResults:
         self.all_hidden = False
 
     def __repr__(self):
-        return pprint.pformat(self.to_dict(), indent=2)
+        return self.summary()
+
+    @classmethod
+    def from_ottr_json(cls, ottr_output):
+        """
+        Creates a ``GradingResults`` object from the JSON output of Ottr.
+
+        Args:
+            ottr_output (``str``): the JSON output of Ottr as a string
+        
+        Returns:
+            ``GradingResults``: the Ottr grading results
+        """
+        test_file_results = json.loads(ottr_output)["test_file_results"]
+        test_files = []
+        for tfr in test_file_results:
+            test_cases, test_case_results = [], []
+
+            for tcr in tfr["test_case_results"]:
+                tc = tcr["test_case"]
+                test_cases.append(TestCase(
+                    name = tc["name"],
+                    body = tc["code"],
+                    hidden = tc["hidden"],
+                    points = tc["points"],
+                    success_message = tc["success_message"],
+                    failure_message = tc["failure_message"],
+                ))
+                test_case_results.append(TestCaseResult(
+                    test_case = test_cases[-1],
+                    message = tcr["error"],
+                    passed = tcr["passed"],
+                ))
+            
+            test_file = OttrTestFile(
+                name = os.path.splitext(os.path.basename(tfr["filename"]))[0],
+                path = tfr["filename"],
+                test_cases = test_cases,
+            )
+            test_file.test_case_results = test_case_results
+            
+            test_files.append(test_file)
+        
+        return cls(test_files)
 
     @property
     def test_files(self):
         """
-        The names of all test files tracked in these grading results
+        ``list[TestFile]``: the names of all test files tracked in these grading results
         """
         return list(self.results.keys())
 
     @property
     def total(self):
         """
-        The total points earned
+        ``int`` or ``float``: the total points earned
         """
         return sum(tr.score for tr in self.results.values())
 
     @property
     def possible(self):
         """
-        The total points possible
+        ``int`` or ``float``: the total points possible
         """
         return sum(tr.possible for tr in self.results.values())
     
